@@ -1,5 +1,5 @@
 package Net::Async::Webservice::UPS;
-$Net::Async::Webservice::UPS::VERSION = '1.0.6';
+$Net::Async::Webservice::UPS::VERSION = '1.0.7';
 {
   $Net::Async::Webservice::UPS::DIST = 'Net-Async-Webservice-UPS';
 }
@@ -160,7 +160,7 @@ around BUILDARGS => sub {
 
 
 sub transaction_reference {
-    my ($args) = @_;
+    my ($self,$args) = @_;
     our $VERSION; # this, and the ||0 later, are to make it work
                   # before dzil munges it
     return {
@@ -307,6 +307,7 @@ sub request_rate {
             @services = sort { $a->total_charges <=> $b->total_charges } @services;
 
             my $ret = Net::Async::Webservice::UPS::Response::Rate->new({
+                customer_context => $response->{Response}{TransactionReference}{CustomerContext},
                 services => \@services,
                 ( $response->{Error} ? (warnings => $response->{Error}) : () ),
             });
@@ -376,6 +377,7 @@ sub validate_address {
 
 
             my $ret = Net::Async::Webservice::UPS::Response::Address->new({
+                customer_context => $response->{Response}{TransactionReference}{CustomerContext},
                 addresses => \@addresses,
                 ( $response->{Error} ? (warnings => $response->{Error}) : () ),
             });
@@ -467,6 +469,7 @@ sub validate_street_address {
             }
 
             my $ret = Net::Async::Webservice::UPS::Response::Address->new({
+                customer_context => $response->{Response}{TransactionReference}{CustomerContext},
                 addresses => \@addresses,
                 ( $response->{Error} ? (warnings => $response->{Error}) : () ),
             });
@@ -546,6 +549,7 @@ sub ship_confirm {
             my $charges = $response->{ShipmentCharges};
 
             return Net::Async::Webservice::UPS::Response::ShipmentConfirm->new({
+                customer_context => $response->{Response}{TransactionReference}{CustomerContext},
                 unit => $weight->{UnitOfMeasurement}{Code},
                 billing_weight => $weight->{Weight},
                 currency => $charges->{TotalCharges}{CurrencyCode},
@@ -611,6 +615,7 @@ sub ship_accept {
             my $charges = $results->{ShipmentCharges};
 
             return Net::Async::Webservice::UPS::Response::ShipmentAccept->new({
+                customer_context => $response->{Response}{TransactionReference}{CustomerContext},
                 unit => $weight->{UnitOfMeasurement}{Code},
                 billing_weight => $weight->{Weight},
                 currency => $charges->{TotalCharges}{CurrencyCode},
@@ -636,7 +641,7 @@ sub ship_accept {
                           }) ) : () ),
                         _base64_if( html => $pr->{LabelImage}{HTMLImage} ),
                         _base64_if( pdf417 => $pr->{LabelImage}{PDF417} ),
-                        _img_if( receipt => $pr->{Receipt} ),
+                        _img_if( receipt => $pr->{Receipt}{Image} ),
                         _img_if( form_image => $pr->{Form} ),
                         _pair_if( form_code => $pr->{Form}{Code} ),
                         _pair_if( form_group_id => $pr->{FormGroupId} ),
@@ -757,7 +762,7 @@ Net::Async::Webservice::UPS - UPS API client, non-blocking
 
 =head1 VERSION
 
-version 1.0.6
+version 1.0.7
 
 =head1 SYNOPSIS
 
