@@ -1,5 +1,5 @@
 package Net::Async::Webservice::UPS::Package;
-$Net::Async::Webservice::UPS::Package::VERSION = '1.0.6';
+$Net::Async::Webservice::UPS::Package::VERSION = '1.0.7';
 {
   $Net::Async::Webservice::UPS::Package::DIST = 'Net-Async-Webservice-UPS';
 }
@@ -8,7 +8,6 @@ use Type::Params qw(compile);
 use Types::Standard qw(Str Object);
 use Net::Async::Webservice::UPS::Types ':types';
 use Net::Async::Webservice::UPS::Exception;
-use Carp;
 use namespace::autoclean;
 use 5.010;
 
@@ -50,7 +49,8 @@ around BUILDARGS => sub {
             $args->{weight_unit} ||= 'KGS';
         }
         else {
-            croak qq{Bad value "$ms" for measurement_system};
+            require Carp;
+            Carp::croak qq{Bad value "$ms" for measurement_system};
         }
     };
     return $args;
@@ -86,6 +86,12 @@ has id => (
     isa => Str,
 );
 
+
+has description => (
+    is => 'rw',
+    isa => Str,
+);
+
 my %code_for_packaging_type = (
     LETTER          => '01',
     PACKAGE         => '02',
@@ -107,6 +113,10 @@ sub as_hash {
         },
     );
 
+    if ($self->description) {
+        $data{Description} = $self->description;
+    }
+
     if ( $self->length || $self->width || $self->height ) {
         $data{Dimensions} = {
             UnitOfMeasurement => {
@@ -227,7 +237,7 @@ Net::Async::Webservice::UPS::Package - a package for UPS
 
 =head1 VERSION
 
-version 1.0.6
+version 1.0.7
 
 =head1 ATTRIBUTES
 
@@ -272,6 +282,11 @@ L</weight_unit>.
 Optional string, may be used to link package-level response parts to
 the packages in a request.
 
+=head2 C<description>
+
+Optional string, description of the package; required when the package
+is used in a return shipment.
+
 =head1 METHODS
 
 =head2 C<weight_unit>
