@@ -1,5 +1,5 @@
 package Net::Async::Webservice::UPS::ReturnService;
-$Net::Async::Webservice::UPS::ReturnService::VERSION = '1.0.6';
+$Net::Async::Webservice::UPS::ReturnService::VERSION = '1.0.7';
 {
   $Net::Async::Webservice::UPS::ReturnService::DIST = 'Net-Async-Webservice-UPS';
 }
@@ -43,9 +43,17 @@ around BUILDARGS => sub {
     my $args = $class->$orig(@etc);
     if ($args->{code} and not $args->{label}) {
         $args->{label} = $label_for_code{$args->{code}};
+        if (!defined $args->{label}) {
+            require Carp;
+            Carp::croak "Bad return service code $args->{code}";
+        }
     }
     elsif ($args->{label} and not $args->{code}) {
         $args->{code} = $code_for_label{$args->{label}};
+        if (!defined $args->{code}) {
+            require Carp;
+            Carp::croak "Bad return service label $args->{label}";
+        }
     }
     return $args;
 };
@@ -67,7 +75,7 @@ Net::Async::Webservice::UPS::ReturnService - shipment return service from UPS
 
 =head1 VERSION
 
-version 1.0.6
+version 1.0.7
 
 =head1 DESCRIPTION
 
